/* 
 * switch-over-tool's sql
 *
 * 0.8.6 or 0.9.0-RC1/RC2 => 0.9.3-4
 *
 * @author yousuke.hara@gmail.com
 */
CREATE TABLE task_groups (
    ID                       integer         NOT NULL
   ,NAME                     varchar(32672)  NOT NULL
   ,DESCRIPTION              varchar(32672)
   ,START_DATE               char(8)                    default NULL
   ,DEADLINE                 char(8)                    default NULL
   ,REGISTERED               char(14)        NOT NULL
   ,MODIFIED                 char(14)        NOT NULL
   ,USER_ID                  integer         NOT NULL
   ,DEL_FLAG                 char(1)         NOT NULL   default '0'
);

CREATE TABLE task_group_activities (
    ID                       integer GENERATED BY DEFAULT AS IDENTITY   NOT NULL
   ,TASK_GROUP_ID            integer       NOT NULL
   ,ACTIVITY_ID              integer       NOT NULL
);

CREATE TABLE task_group_relations (
    ID                       integer GENERATED BY DEFAULT AS IDENTITY   NOT NULL
   ,TASK_GROUP_ID            integer       NOT NULL
   ,TASK_ID                  integer       NOT NULL
);

CREATE TABLE task_group_comment_bodies (
    ID                       integer GENERATED BY DEFAULT AS IDENTITY   NOT NULL
   ,TASK_GROUP_ID            integer       NOT NULL
   ,REV                      integer       NOT NULL   default 1
   ,BODY                     varchar(32672)          NOT NULL
);

CREATE TABLE task_reviews (
    ID                       integer GENERATED BY DEFAULT AS IDENTITY   NOT NULL
   ,REVIEW_DATE              char(14)      NOT NULL
   ,USER_ID                  integer       NOT NULL
);

CREATE TABLE task_rsslet_tokens (
    ID                       integer GENERATED BY DEFAULT AS IDENTITY   NOT NULL
   ,TASK_ID                  integer       NOT NULL
   ,TOKEN                    char(20)      NOT NULL
);

CREATE TABLE versions (
    ID                       integer GENERATED BY DEFAULT AS IDENTITY   NOT NULL
   ,MAJOUR_NUM               integer       NOT NULL
   ,MINOR_NUM                integer       NOT NULL
   ,MAINTENANCE_NUM          integer       NOT NULL
   ,MAINTENANCE_SUB          integer       NOT NULL
   ,REGISTERED               char(14)      NOT NULL
);

--
-- primary key.
--
ALTER TABLE task_groups 
  ADD CONSTRAINT task_groups_pk 
  PRIMARY KEY (ID);

ALTER TABLE task_group_activities 
  ADD CONSTRAINT task_group_activities_pk 
  PRIMARY KEY (ID);

ALTER TABLE task_group_relations 
  ADD CONSTRAINT task_group_relations_pk 
  PRIMARY KEY (ID);
  
ALTER TABLE task_group_comment_bodies 
  ADD CONSTRAINT task_group_comment_bodies_pk 
  PRIMARY KEY (ID);
  
ALTER TABLE task_reviews 
  ADD CONSTRAINT task_reviews_pk 
  PRIMARY KEY (ID);

ALTER TABLE task_rsslet_tokens 
  ADD CONSTRAINT task_rsslet_tokens_pk 
  PRIMARY KEY (ID);

ALTER TABLE versions 
  ADD CONSTRAINT versions_pk 
  PRIMARY KEY (ID);

--
-- foreign key.
--
ALTER TABLE task_groups 
  ADD FOREIGN KEY (USER_ID) 
  REFERENCES users(ID);

ALTER TABLE task_group_activities 
  ADD FOREIGN KEY (TASK_GROUP_ID) 
  REFERENCES task_groups(ID);
  
ALTER TABLE task_group_activities 
  ADD FOREIGN KEY (ACTIVITY_ID) 
  REFERENCES activities(ID);

ALTER TABLE task_group_relations 
  ADD FOREIGN KEY (TASK_GROUP_ID) 
  REFERENCES task_groups(ID);
  
ALTER TABLE task_group_relations 
  ADD FOREIGN KEY (TASK_ID) 
  REFERENCES tasks(ID);
  
ALTER TABLE task_group_comment_bodies 
  ADD FOREIGN KEY (TASK_GROUP_ID) 
  REFERENCES task_groups(ID);

ALTER TABLE task_reviews 
  ADD FOREIGN KEY (USER_ID) 
  REFERENCES users(ID);

ALTER TABLE task_rsslet_tokens 
  ADD FOREIGN KEY (TASK_ID)
  REFERENCES tasks(ID);

--
-- update tables.
--
DROP table web_service_securities;

CREATE TABLE web_service_securities (
    NONCE                   char(20)      NOT NULL
   ,CREATED_AT              char(20)      NOT NULL
   ,CLIENT_ADDRESS          varchar(256)  NOT NULL
);
ALTER TABLE web_service_securities
  ADD CONSTRAINT web_service_securities_pk
  PRIMARY KEY (NONCE,CREATED_AT);

ALTER TABLE meeting_agendas DROP COLUMN priority;
ALTER TABLE meeting_agendas ADD COLUMN STATUS char(1) NOT NULL DEFAULT '0';

--
-- version
--
INSERT INTO versions (
    majour_num
   ,minor_num
   ,maintenance_num
   ,maintenance_sub
   ,registered
) VALUES (
  0,9,3,0,'20080612190000'
);

--
-- feed tokens
--
DROP TABLE feed_tokens;
CREATE TABLE feed_tokens (
    ID                       integer GENERATED BY DEFAULT AS IDENTITY   NOT NULL
   ,TOKEN                    char(36)      NOT NULL
   ,ACTIVITY_ID              integer
   ,USER_ID                  integer       NOT NULL
   ,DEL_FLAG                 char(1)       NOT NULL
   ,CREATED_AT               char(14)      NOT NULL
);
ALTER TABLE feed_tokens
  ADD CONSTRAINT feed_tokens_pk
  PRIMARY KEY (ID);
  
ALTER TABLE feed_tokens 
  ADD FOREIGN KEY (ACTIVITY_ID) 
  REFERENCES activities(ID);
  
ALTER TABLE feed_tokens 
  ADD FOREIGN KEY (USER_ID) 
  REFERENCES users(ID);
  
--
-- task_collection_of_records
--
CREATE TABLE task_collection_of_records (
    ID                      integer GENERATED BY DEFAULT AS IDENTITY   NOT NULL
   ,COLLECT_TYPE            char(1)       NOT NULL
   ,FULL_DATE               char(8)       NOT NULL
   ,TASK_ID                 integer       NOT NULL
   ,ACTIVITY_ID             integer       NOT NULL
   ,STATUS_ID               integer       NOT NULL
   ,CLASSIFICATION_ID       integer       NOT NULL
   ,PERSON_IN_CHARGE_ID     integer       NOT NULL
   ,CREATED_AT              char(14)      NOT NULL
);
ALTER TABLE task_collection_of_records
  ADD CONSTRAINT task_collection_of_records_pk
  PRIMARY KEY (ID);
ALTER TABLE task_collection_of_records 
  ADD FOREIGN KEY (TASK_ID) 
  REFERENCES tasks(ID);
ALTER TABLE task_collection_of_records 
  ADD FOREIGN KEY (ACTIVITY_ID) 
  REFERENCES activities(ID);
ALTER TABLE task_collection_of_records 
  ADD FOREIGN KEY (STATUS_ID) 
  REFERENCES task_statuses(ID);
ALTER TABLE task_collection_of_records 
  ADD FOREIGN KEY (CLASSIFICATION_ID) 
  REFERENCES classifications(ID);
ALTER TABLE task_collection_of_records 
  ADD FOREIGN KEY (PERSON_IN_CHARGE_ID) 
  REFERENCES users(ID);

-- update meeting agenda.status
UPDATE meeting_agendas 
SET status = '3'
WHERE
    id IN (
        SELECT D.agenda_id
        FROM meeting_agenda_discussions D
        WHERE
            D.type = '2'
        GROUP BY D.agenda_id
    );
/* end   */

show tables;
exit;